@@ -21,6 +21,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <string.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -489,12 +490,7 @@ gphotofs_mknod(const char *path, mode_t mode, dev_t rdev)
       gp_file_unref (cfile);
       return -1;
    }
-   res = gp_file_set_name (cfile, file);
-   if (res < 0) {
-      gp_file_unref (cfile);
-      return -1;
-   }
-   res = gp_camera_folder_put_file (p->camera, dir, cfile,
+   res = gp_camera_folder_put_file (p->camera, dir, file, GP_FILE_TYPE_NORMAL, cfile,
 				    p->context);
    gp_file_unref (cfile);
    g_free(dir);
@@ -526,13 +522,8 @@ static int gphotofs_flush(const char *path, struct fuse_file_info *fi)
 	 gp_file_unref (file);
 	 return -1;
       }
-      res = gp_file_set_name (file, openFile->destname);
-      if (res < 0) {
-	 gp_file_unref (file);
-	 return -1;
-      }
       res = gp_camera_file_delete(p->camera, openFile->destdir, openFile->destname, p->context);
-      res = gp_camera_folder_put_file (p->camera, openFile->destdir, file, p->context);
+      res = gp_camera_folder_put_file (p->camera, openFile->destdir, openFile->destname, GP_FILE_TYPE_NORMAL, file, p->context);
       if (res < 0)
 	 return -ENOSPC;
       gp_file_unref (file);
@@ -687,13 +678,15 @@ gphotofs_init()
    gp_abilities_list_load(p->abilities, p->context);
 
    if (sSpeed) {
-      GPPortInfo info;
+      GPPortInfo	info;
+      GPPortType	type;
 
       /* Make sure we've got a serial port. */
       ret = gp_camera_get_port_info(p->camera, &info);
+      gp_port_info_get_type (info, &type);
       if (ret != 0) {
          goto error;
-      } else if (info.type != GP_PORT_SERIAL) {
+      } else if (type != GP_PORT_SERIAL) {
          g_fprintf(stderr, "%s\n", _("You can only specify speeds for serial ports."));
          goto error;
       }
@@ -726,6 +719,7 @@ gphotofs_init()
          goto error;
       }
 
+      /* Marcus: why save it? puzzling. */
       ret = gp_setting_set("gphoto2", "model", a.model);
       if (ret != 0) {
          goto error;
@@ -753,25 +747,26 @@ gphotofs_init()
                    _("The port you specified ('%s') can not "
                      "be found. Please specify one of the ports "
                      "found by 'gphoto2 --list-ports' make sure "
-                     "the speilling is correct (i.e. with prefix "
+                     "the spelling is correct (i.e. with prefix "
                      "'serial:' or 'usb:')."), sPort);
          g_fprintf(stderr, "\n");
          goto error;
-      } else if (p < 0) {
+      } else if (i < 0) {
          ret = i;
          goto error;
       } else {
+	 char *xpath;
          ret = gp_port_info_list_get_info(il, i, &info);
          if (ret != 0) {
             goto error;
          }
 
          ret = gp_camera_set_port_info (p->camera, info);
-         if (ret != 0) {
+         if (ret != 0)
             goto error;
-         }
-
-         gp_setting_set("gphoto2", "port", info.path);
+         /* Marcus: why save it? puzzling. */
+	 gp_port_info_get_path (info, &xpath);
+         gp_setting_set("gphoto2", "port", xpath);
 
          gp_port_info_list_free(il);
       }
